Index: device/usb/usb_device.h |
diff --git a/device/usb/usb_device.h b/device/usb/usb_device.h |
index 586fd19cdce706c59b50c48b3ed621b95e22ea3f..a012025b35784be2a1e1f90f467e80c9d1938973 100644 |
--- a/device/usb/usb_device.h |
+++ b/device/usb/usb_device.h |
@@ -12,7 +12,7 @@ |
namespace device { |
class UsbDeviceHandle; |
-class UsbConfigDescriptor; |
+struct UsbConfigDescriptor; |
// A UsbDevice object represents a detected USB device, providing basic |
// information about it. For further manipulation of the device, a |
@@ -44,10 +44,9 @@ class UsbDevice : public base::RefCountedThreadSafe<UsbDevice> { |
// Blocking method. Must be called on FILE thread. |
virtual bool Close(scoped_refptr<UsbDeviceHandle> handle) = 0; |
// Lists the interfaces provided by the device and fills the given |
// UsbConfigDescriptor. |
// Blocking method. Must be called on FILE thread. |
- virtual scoped_refptr<UsbConfigDescriptor> ListInterfaces() = 0; |
+ virtual const UsbConfigDescriptor& GetConfiguration() = 0; |
protected: |
UsbDevice(uint16 vendor_id, uint16 product_id, uint32 unique_id) |
@@ -44,10 +44,9 @@ class UsbDevice : public base::RefCountedThreadSafe<UsbDevice> { |
// Blocking method. Must be called on FILE thread. |
virtual bool Close(scoped_refptr<UsbDeviceHandle> handle) = 0; |
- // Lists the interfaces provided by the device and fills the given |
- // UsbConfigDescriptor. |
+ // Gets the UsbConfigDescriptor for the active device configuration. |
// Blocking method. Must be called on FILE thread. |